Delanocreds wallet code
Delanocreds Wallet Core
A crate which provides the core functionality for the Delanocreds wallet. This can then be wrapped by other utilities such as wasm-bindgen, etc.
Structs
- Delano
Wallet - Delano Wallet
- Issue
Options - Optionally pass in NymProof and.or None when issuing credentials
- Offer
Config - Configure the Offer: Optionally pass in Selectables and/or an additional Entry. Optionally set the maximum number of entries that can be added to the credential.
- Provables
- Values needed to be passed to the
provefunction. - Proven
- Values needed to be passed to the
verifyfunction. - Selectables
- Specifies what Entrys to include, and which Attributes to exclude from the cred.
- Verifiables
- Values needed to be passed to the
verifyfunction.